LeaderboardEntry class

A single entry on the referral leaderboard.

Constructors

LeaderboardEntry({required String referrerId, String? referrerName, required int total, required int completed, required int pending, String? totalRewardValue})
Creates a LeaderboardEntry instance.
const
LeaderboardEntry.fromJson(Map<String, dynamic> json)
Creates a LeaderboardEntry from a JSON map.
factory

Properties

completed int
Number of completed referrals.
final
hashCode int
The hash code for this object.
no setteroverride
pending int
Number of pending referrals.
final
referrerId String
The user ID of the referrer.
final
referrerName String?
Optional display name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
Total number of referrals.
final
totalRewardValue String?
Total reward value as a string, if applicable.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this entry to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override