Analytics class
Provides analytics event tracking via the Tolinku API.
Events are queued in memory and sent in batches. The queue is flushed
automatically when it reaches _batchSize events, every _flushInterval,
or when flush or dispose is called.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Releases resources held by this instance.
-
flush(
) → Future< void> - Flushes all queued events to the server.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
track(
String eventType, {Map< String, dynamic> ? properties}) → Future<void> - Tracks a custom event.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited